@@ -19,7 +19,7 @@ extern crate regex;
 mod derive_enum;
 mod derive_input_object;
 mod derive_object;
-mod derive_juniper_scalar_value;
+mod derive_scalar_value;
 mod util;
 
 use proc_macro::TokenStream;
@@ -27,14 +27,30 @@ use proc_macro::TokenStream;
 #[proc_macro_derive(GraphQLEnum, attributes(graphql))]
 pub fn derive_enum(input: TokenStream) -> TokenStream {
     let ast = syn::parse::<syn::DeriveInput>(input).unwrap();
-    let gen = derive_enum::impl_enum(&ast);
+    let gen = derive_enum::impl_enum(&ast, false);
+    gen.into()
+}
+
+#[proc_macro_derive(GraphQLEnumInternal, attributes(graphql))]
+#[doc(hidden)]
+pub fn derive_enum_internal(input: TokenStream) -> TokenStream {
+    let ast = syn::parse::<syn::DeriveInput>(input).unwrap();
+    let gen = derive_enum::impl_enum(&ast, true);
     gen.into()
 }
 
 #[proc_macro_derive(GraphQLInputObject, attributes(graphql))]
 pub fn derive_input_object(input: TokenStream) -> TokenStream {
     let ast = syn::parse::<syn::DeriveInput>(input).unwrap();
-    let gen = derive_input_object::impl_input_object(&ast);
+    let gen = derive_input_object::impl_input_object(&ast, false);
+    gen.into()
+}
+
+#[proc_macro_derive(GraphQLInputObjectInternal, attributes(graphql))]
+#[doc(hidden)]
+pub fn derive_input_object_internal(input: TokenStream) -> TokenStream {
+    let ast = syn::parse::<syn::DeriveInput>(input).unwrap();
+    let gen = derive_input_object::impl_input_object(&ast, true);
     gen.into()
 }
 
@@ -46,8 +62,16 @@ pub fn derive_object(input: TokenStream) -> TokenStream {
 }
 
 #[proc_macro_derive(ScalarValue)]
-pub fn derive_juniper_scalar_value(input: TokenStream) -> TokenStream {
+pub fn derive_scalar_value(input: TokenStream) -> TokenStream {
     let ast = syn::parse::<syn::DeriveInput>(input).unwrap();
-    let gen = derive_juniper_scalar_value::impl_scalar_value(&ast);
+    let gen = derive_scalar_value::impl_scalar_value(&ast, false);
+    gen.into()
+}
+
+#[proc_macro_derive(GraphQLScalarValueInternal)]
+#[doc(hidden)]
+pub fn derive_scalar_value_internal(input: TokenStream) -> TokenStream {
+    let ast = syn::parse::<syn::DeriveInput>(input).unwrap();
+    let gen = derive_scalar_value::impl_scalar_value(&ast, true);
     gen.into()
 }
